@@ -6,7 +6,7 @@
 /*                                                   */
 /* Author and (c) 1999-2004: Amon Ott <ao@rsbac.org> */
 /* Copyright (c) 2004-2005 H+BEDV Datentechnik GmbH  */
-/* Copyright (c) 2006 Avira GmbH                     */
+/* Copyright (c) 2006-2007 Avira GmbH                */
 /* Written by John Ogness <john.ogness@avira.com>    */
 /*                                                   */
 /* Last modified: 2/Nov/2006                         */
@@ -554,24 +554,18 @@ inline int xp_sys_unhook()
 {
 	/* Called by rmmod when removing the module. */
 
-	int	error;
-
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
-	error = unregister_chrdev(dev_major, DEVICE_NAME);
+	unregister_chrdev(dev_major, DEVICE_NAME);
 
 	devfs_remove(DEVICE_NAME);
 #else
 	#ifdef CONFIG_DEVFS_FS
-		error = devfs_unregister_chrdev(dev_major, DEVICE_NAME);
+		devfs_unregister_chrdev(dev_major, DEVICE_NAME);
 		devfs_unregister(devfs_find_handle(NULL, DEVICE_NAME, dev_major, 0, DEVFS_SPECIAL_CHR, 0));
 	#else
-		error = unregister_chrdev(dev_major, DEVICE_NAME);
+		unregister_chrdev(dev_major, DEVICE_NAME);
 	#endif
 #endif
-	if (error < 0)
-	{
-		xp_print("dazuko: error unregistering chrdev, err=%d\n", error);
-	}
 
 	return 0;
 }
