@@ -80,8 +80,6 @@ KlamDB::KlamDB( QWidget* parent, const char* name, bool modal, WFlags fl )
 
     VirusList = new KListView( privateLayoutWidget, "VirusList" );
     VirusList->addColumn( i18n( "All Known Viruses" ),150 );
-/*    VirusList->setResizeMode(QListView::AllColumns);
-    VirusList->setColumnWidthMode(0,QListView::Maximum);*/
     connect(VirusList, SIGNAL( doubleClicked( QListViewItem * , const QPoint &, int ) ),
                     this, SLOT(slotOpenTab(QListViewItem * , const QPoint &, int )) );
 
@@ -91,32 +89,32 @@ KlamDB::KlamDB( QWidget* parent, const char* name, bool modal, WFlags fl )
     QPixmap vicon;
     QPixmap ticon;
 
-        QString iconPath = locate("cache", KMimeType::favIconForURL("http://www.viruspool.net")+".png");
-        if ( iconPath.isEmpty() )
-          vicon = SmallIcon("find");
-        else
-          vicon = QPixmap( iconPath );
+    QString iconPath = locate("cache", KMimeType::favIconForURL("http://www.viruspool.net")+".png");
+    if ( iconPath.isEmpty() )
+      vicon = SmallIcon("find");
+    else
+      vicon = QPixmap( iconPath );
 
-        iconPath = locate("cache", KMimeType::favIconForURL("http://www.google.com")+".png");
-        if ( iconPath.isEmpty() )
-          gicon = SmallIcon("find");
-        else
-          gicon = QPixmap( iconPath );
+    iconPath = locate("cache", KMimeType::favIconForURL("http://www.google.com")+".png");
+    if ( iconPath.isEmpty() )
+      gicon = SmallIcon("find");
+    else
+      gicon = QPixmap( iconPath );
 
-        iconPath = locate("cache", KMimeType::favIconForURL("http://www.trendmicro.com")+".png");
-        if ( iconPath.isEmpty() )
-          ticon = SmallIcon("find");
-        else
-          ticon = QPixmap( iconPath );
+    iconPath = locate("cache", KMimeType::favIconForURL("http://www.trendmicro.com")+".png");
+    if ( iconPath.isEmpty() )
+      ticon = SmallIcon("find");
+    else
+      ticon = QPixmap( iconPath );
 
-        menu->insertItem(vicon, i18n("Search in VirusList"), this,SLOT(slotVirusList()) );
-        menu->insertItem(vicon, i18n("Search in VirusPool"), this,SLOT(slotVirusPool()) );
-        menu->insertItem(ticon, i18n("Search with Trend Micro"), this,SLOT(slotTrendMicro()) );
-        menu->insertItem(gicon, i18n("Search with Google"), this,SLOT(slotGoogle()) );
+    menu->insertItem(vicon, i18n("Search in VirusList"), this,SLOT(slotVirusList()) );
+    menu->insertItem(vicon, i18n("Search in VirusPool"), this,SLOT(slotVirusPool()) );
+    menu->insertItem(ticon, i18n("Search with Trend Micro"), this,SLOT(slotTrendMicro()) );
+    menu->insertItem(gicon, i18n("Search with Google"), this,SLOT(slotGoogle()) );
+
+    connect(VirusList, SIGNAL( contextMenuRequested( QListViewItem *, const QPoint& , int ) ), 
+    this, SLOT( slotRMB( QListViewItem *, const QPoint &, int ) ) );
 
-        connect(VirusList, SIGNAL( contextMenuRequested( QListViewItem *, const QPoint& , int ) ), 
-        this, SLOT( slotRMB( QListViewItem *, const QPoint &, int ) ) );
-    
     kLineEdit1 = new KListViewSearchLine( (QWidget *)searchToolBar, VirusList,"klinedit1");
     QValueList<int> columns;
         columns.append(0);
@@ -131,10 +129,8 @@ KlamDB::KlamDB( QWidget* parent, const char* name, bool modal, WFlags fl )
     
 
     languageChange();
-    //resize( QSize(600, 480).expandedTo(minimumSizeHint()) );
     clearWState( WState_Polished );
     
-    //listdir((const char *)QString("/home/robert/.klamav/database"));
     slotOpenHome();
 }
 
@@ -210,15 +206,6 @@ int KlamDB::listdb(const char *filename)
         delete tf;
         return -1;
     }
-    //dir = tf.name();
-    
-    //kdDebug() << tf->name() << endl;
-//     if(mkdir(tf->name(), 0700)) {
-//         printf("!listdb(): Can't create temporary directory \n");
-//         free(buffer);
-//         fclose(fd);
-//         return -1;
-//     }
 
     /* FIXME: it seems there is some problem with current position indicator
     * after gzdopen() call in cli_untgz(). Temporarily we need this wrapper:
@@ -226,12 +213,7 @@ int KlamDB::listdb(const char *filename)
 
     /* start */
 
-/*    tmp = cli_gentemp(tmpdir);*/
     KTempFile* tn = new KTempFile(tf->name());
-    //tn->close();
-    //tn->unlink();
-
-    //kdDebug() << tn->name() << endl;
     
     if((tmpd = fopen(tn->name(), "wb+")) == NULL) {
         printf("!listdb(): Can't create temporary file \n");
