@@ -9,6 +9,7 @@
 #include "collectiondb.h"
 /*#include "gmanedb.h"*/
 #include "klamavconfig.h"
+#include "config.h"
 
 #include <klocale.h>
 #include <kio/netaccess.h>
@@ -151,11 +152,12 @@ Freshklam::Freshklam(QWidget *parent, const char *name)
     connect( klamav_options, SIGNAL( clicked() ), this,
 		SLOT( checkForNewKlamAVNow() ) );
 
-
-
-
-
-
+#ifdef DISABLE_UPDATES
+    clamav_box->setEnabled(false);
+    klamav_box->setEnabled(false);
+    clamav_options->setEnabled(false);
+    klamav_options->setEnabled(false);
+#endif
     //Virus Database Directory
     QGroupBox *group = new QGroupBox(i18n("Virus Database Directory"), this);
     vbox->addWidget(group);
